# Skills

Local skills for testing and development.

## Structure

```
skills/
├── skill-creator/     # Guide for creating skills
├── skill-evaluator/   # Evaluate skills against best practices
├── claude-code/       # Claude Code related skills
└── notion-skills/     # Notion integration skills
```

## Usage

Set `SKILLPORT_SKILLS_DIR=.agent/skills` to load these skills.
